@@ -45,6 +45,7 @@ import logging
 from diffenator import CHOICES, __version__
 from diffenator.font import DFont, font_matcher
 from diffenator.diff import DiffFonts
+from diffenator.constants import FTHintMode
 import argparse
 
 
@@ -93,6 +94,9 @@ def main():
                               "pixel diffs."))
     parser.add_argument('-r', '--render-path',
                         help="Path to generate before and after gifs to.")
+    parser.add_argument('--ft-hinting', type=str, default="unhinted",
+                        choices=[e.name.lower() for e in FTHintMode],
+                        help="Set FreeType hinting mode")
     args = parser.parse_args()
 
     logger = logging.getLogger("fontdiffenator")
@@ -110,8 +114,9 @@ def main():
             render_path=args.render_path,
             html_output=args.html,
     )
-    font_before = DFont(args.font_before)
-    font_after = DFont(args.font_after)
+    ft_hint_mode = int(getattr(FTHintMode, args.ft_hinting.upper()))
+    font_before = DFont(args.font_before, ft_load_glyph_flags=ft_hint_mode)
+    font_after = DFont(args.font_after, ft_load_glyph_flags=ft_hint_mode)
     font_matcher(font_before, font_after, args.vf_instance)
 
     diff = DiffFonts(font_before, font_after, diff_options)
