@@ -1,5 +1,4 @@
 """Module for DFont"""
-from fontTools.misc.py23 import unichr
 from fontTools.ttLib import TTFont, newTable
 from fontTools.pens.ttGlyphPen import TTGlyphPen
 from fontTools.varLib.mutator import instantiateVariableFont
@@ -190,8 +189,8 @@ class DFont(TTFont):
         subfamilyname = static_font.ttfont['name'].getName(2, 3, 1, 1033)
         typosubfamilyname = static_font.ttfont['name'].getName(17, 3, 1, 1033)
 
-        subfamilyname = typosubfamilyname.toUnicode() if typosubfamilyname else \
-            subfamilyname.toUnicode()
+        anysubfamilyname = typosubfamilyname or subfamilyname
+        subfamilyname = anysubfamilyname.toUnicode() if anysubfamilyname else ""
 
         # The Google Fonts v1 api can only handle the wght axis. For families
         # which have widths, we have to release them as a seperate family,
@@ -225,7 +224,7 @@ class DFont(TTFont):
         if parsed_weight:
             variations["wght"] = WEIGHT_NAME_TO_FVAR[parsed_weight]
         else:
-            logger.debug(f"Couldn't parse weight value from {dfont.path}")
+            logger.debug(f"Couldn't parse weight value from {static_font.path}")
             weight_class = static_font.ttfont["OS/2"].usWeightClass
             # Google Fonts used to set the usWeightClass of Thin static
             # fonts to 250 and the ExtraLight to 275. Override these
@@ -319,8 +318,8 @@ class InputGenerator(HbInputGenerator):
 
         # see if this glyph has a simple unicode mapping
         if name in self.reverse_cmap:
-            text = unichr(self.reverse_cmap[name])
-            if text != unichr(0):
+            text = chr(self.reverse_cmap[name])
+            if text != chr(0):
                 inputs.append(((), text))
 
         # check the substitution features
